@@ -16,7 +16,7 @@ function deploy_bifrost {
     # Deploy the bifrost container.
     # TODO(mgoddard): add pull action when we have a local registry service in
     # CI.
-    kolla-ansible -i ${RAW_INVENTORY} -vvv deploy-bifrost &> /tmp/logs/ansible/deploy-bifrost
+    kolla-ansible deploy-bifrost -i ${RAW_INVENTORY} -vvv  &> /tmp/logs/ansible/deploy-bifrost
 }
 
 
